@@ -19,20 +19,22 @@ func MergeCmd() *cobra.Command {
 	}
 
 	cmd.Flags().StringP("branch", "B", "multi-gitter-branch", "The name of the branch where changes are committed.")
-	cmd.Flags().StringSliceP("merge-type", "", []string{"merge", "squash", "rebase"}, "The type of merge that should be done (GitHub). Multiple types can be used as backup strategies if the first one is not allowed.")
+	cmd.Flags().StringSliceP("merge-type", "", []string{"merge", "squash", "rebase"},
+		"The type of merge that should be done (GitHub). Multiple types can be used as backup strategies if the first one is not allowed.")
 	configurePlatform(cmd)
+	configureRunPlatform(cmd, false)
 	configureLogging(cmd, "-")
 	configureConfig(cmd)
 
 	return cmd
 }
 
-func merge(cmd *cobra.Command, args []string) error {
+func merge(cmd *cobra.Command, _ []string) error {
 	flag := cmd.Flags()
 
 	branchName, _ := flag.GetString("branch")
 
-	vc, err := getVersionController(flag, true)
+	vc, err := getVersionController(flag, true, false)
 	if err != nil {
 		return err
 	}
