@@ -21,6 +21,7 @@ func StatusCmd() *cobra.Command {
 
 	cmd.Flags().StringP("branch", "B", "multi-gitter-branch", "The name of the branch where changes are committed.")
 	configurePlatform(cmd)
+	configureRunPlatform(cmd, false)
 	configureLogging(cmd, "-")
 	configureConfig(cmd)
 	cmd.Flags().AddFlagSet(outputFlag())
@@ -28,13 +29,13 @@ func StatusCmd() *cobra.Command {
 	return cmd
 }
 
-func status(cmd *cobra.Command, args []string) error {
+func status(cmd *cobra.Command, _ []string) error {
 	flag := cmd.Flags()
 
 	branchName, _ := flag.GetString("branch")
 	strOutput, _ := flag.GetString("output")
 
-	vc, err := getVersionController(flag, true)
+	vc, err := getVersionController(flag, true, false)
 	if err != nil {
 		return err
 	}
